@@ -180,7 +180,7 @@ def opt(self, y_rfl, pt0, rho_0=[{"method": "const", "value": 0.1},
         ssei[ssei > 1e10] = 1e10
 
     if len(ssai) != len(self.scale_dn):  # not all errors given, assume that first ones are given
-        bf = np.ones(len(self.scale_dn), dtype=np.float)
+        bf = np.ones(len(self.scale_dn), dtype=float)
         bf[:len(ssai)] = ssai[:]
         ssai = bf
 
@@ -411,8 +411,8 @@ class Rj2RhoJ_LinInterp(object):
         self.rho_wvl = rho_wvl_lin_int(**kwargs)
         self.n_rho_lin = len(self.rho_wvl)
 
-        self.rho = np.zeros(self.n_wvl, dtype=np.float)
-        self.J_rho = np.zeros((self.n_rho_lin, self.n_wvl), dtype=np.float)
+        self.rho = np.zeros(self.n_wvl, dtype=float)
+        self.J_rho = np.zeros((self.n_rho_lin, self.n_wvl), dtype=float)
 
     def __call__(self, rj):
         int_rho(self.n_rho_lin, self.rho_wvl, rj, self.n_wvl, self.wvl, self.rho, self.J_rho)
@@ -857,7 +857,7 @@ class RtFo(object):
         if idx is None:
             tble["idx"] = np.arange(tble["n_dims"])
         else:
-            tble["idx"] = np.array([idx.index(dim) for dim in tble["dims"][:-1]], dtype=np.int)
+            tble["idx"] = np.array([idx.index(dim) for dim in tble["dims"][:-1]], dtype=int)
 
         # instance the n-dimensional interpolation function (n = number of dimensions of atmospheric state)
         tble["int"] = self.interp[tble["n_dims"]].intp(data=tble["dat"],
@@ -1192,7 +1192,7 @@ class RtFo(object):
                 _ = rng.pop(rdx)
                 jac = np.delete(jac, rdx, axis=0)
 
-        idx = np.array(idx, dtype=np.int)
+        idx = np.array(idx, dtype=int)
 
         for key, val in [("dat", dat), ("idx", idx), ("dims", dms), ("range", rng), ("jacobean_switch", jac)]:
             fkt["%s_%s" % (key, reduce_suffix)] = val
@@ -1261,9 +1261,9 @@ class RtFo(object):
         :return: numpy array with ints which give the closest indices to the wavelength in data_wvls
         """
         if sensor_name is None:
-            return np.array([np.argmin(np.abs(data_wvls - wv)) for wv in self.wvl], dtype=np.int)
+            return np.array([np.argmin(np.abs(data_wvls - wv)) for wv in self.wvl], dtype=int)
         else:
-            return np.array([np.argmin(np.abs(data_wvls - wv)) for wv in self.wvl_sensors[sensor_name]], dtype=np.int)
+            return np.array([np.argmin(np.abs(data_wvls - wv)) for wv in self.wvl_sensors[sensor_name]], dtype=int)
 
 
 # noinspection PyProtectedMember,PyDictCreation,PyUnresolvedReferences
@@ -1275,14 +1275,14 @@ def __minimize__(pt_index, p0, pt_names, data, opt_func, zoom_factor=None, opt_r
         opt_options = {"maxiter": 50, "disp": False}
 
     if processes is None:
-        processes = np.max([1, np.int(np.ceil(cpu_count() / 2) - 2)])
+        processes = np.max([1, int(np.ceil(cpu_count() / 2) - 2)])
 
     if zoom_factor is None:
-        zoom_factor = np.ones(3, dtype=np.float)
+        zoom_factor = np.ones(3, dtype=float)
     elif len(zoom_factor) == 1:
-        zoom_factor = np.array([zoom_factor, zoom_factor, 1.0], dtype=np.float)
+        zoom_factor = np.array([zoom_factor, zoom_factor, 1.0], dtype=float)
     elif len(zoom_factor) == 2:
-        zoom_factor = np.array([zoom_factor[0], zoom_factor[1], 1.0], dtype=np.float)
+        zoom_factor = np.array([zoom_factor[0], zoom_factor[1], 1.0], dtype=float)
     else:
         raise ValueError("Wrong zoom_factor")
 
@@ -1417,7 +1417,7 @@ def __min__(ii, debug=False, only_success=False):
 
 def __rezoom__(res, data_shape, order=3):
     from scipy.ndimage import zoom  # import here to avoid static TLS ImportError
-    sh0, sh1 = np.array(res.shape, dtype=np.float), np.array(res.shape, dtype=np.float)
+    sh0, sh1 = np.array(res.shape, dtype=float), np.array(res.shape, dtype=float)
     sh1[:2] = np.array(data_shape)[:2]
     fac = sh1 / sh0
     if np.mean(fac) == 1.0:
@@ -1453,13 +1453,13 @@ class FF(object):
         if not all([dim in self.fo.L0["dims"] for dim in self.optimize_dims_atm]):
             raise ValueError("Missing:", self.optimize_dims_atm, self.fo.L0["dims"])
 
-        self.atm_idx = np.array([idx for dim, idx in zip(self.fo.L0["dims"], self.fo.L0["idx"])], dtype=np.int)
+        self.atm_idx = np.array([idx for dim, idx in zip(self.fo.L0["dims"], self.fo.L0["idx"])], dtype=int)
         self.atm_opt_idx = np.array(
             [idx for dim, idx in zip(self.fo.L0["dims"], self.fo.L0["idx"]) if dim in self.optimize_dims_atm],
-            dtype=np.int)
+            dtype=int)
         self.atm_bgr_idx = np.array(
             [idx for dim, idx in zip(self.fo.L0["dims"], self.fo.L0["idx"]) if dim not in self.optimize_dims_atm],
-            dtype=np.int)
+            dtype=int)
 
         dim_names = list(optimize_dims_atm) + [self.fo.dim_names[dx] for dx in self.atm_bgr_idx]
         self.dim_names = [dim for dim in self.fo.L0["dims"] if dim in dim_names] + self.n_rho_lin * ["rj"]
@@ -1471,7 +1471,7 @@ class FF(object):
 
         self.pt = np.zeros(np.max(self.fo.L0["idx"]) + 1 +  # atmospheric indices
                            self.fo.n_rho_lin,  # surface indices
-                           dtype=np.float)
+                           dtype=float)
         self.pt_bounds_up = np.zeros(len(self.pt))
         self.pt_bounds_dn = np.zeros(len(self.pt))
         for ii, idx in enumerate(self.fo.L0["idx"]):
@@ -1588,7 +1588,7 @@ class FF(object):
             if xx_is_scaled:
                 j = j * self.jjsc
 
-            n = np.float(len(dt))
+            n = float(len(dt))
             return f / n, j[self.jac_sel] / n
 
 
