@@ -26,7 +26,6 @@
 
 import numpy as np
 from multiprocessing import Pool
-import platform
 from tqdm import tqdm
 
 from sicor.Tools.EnMAP.multiprocessing import initializer
@@ -106,10 +105,11 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
     # about geographic or 3D locations
     row_grid, col_grid = np.meshgrid(np.arange(rows), np.arange(cols))
     locations = np.array([col_grid.flatten(), row_grid.flatten()]).T
-    locations_subset = np.zeros((segs, 2))
 
     if land_only:
         lbl = np.unique(labels)[1:]
+        segs = len(lbl)
+        locations_subset = np.zeros((segs, 2))
 
         for ii, idx in enumerate(lbl):
             locations_subset[ii, :] = locations[labels.flat == idx, :].mean(axis=0)
@@ -122,8 +122,9 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
 
         unique_labels = np.arange(0, np.max(lbl) + 1 - len(missing_labels), 1)
     else:
+        locations_subset = np.zeros((segs, 2))
         for i in range(segs):
-            if np.count_nonzero(segs == 1) == 0:
+            if np.count_nonzero(segs == i) == 0:
                 pass
             else:
                 locations_subset[i, :] = locations[labels.flat == i, :].mean(axis=0)
@@ -135,7 +136,7 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
             if ii not in unique_labels:
                 missing_labels.append(ii)
 
-        unique_labels = np.arange(0, np.max(unique_labels) - len(missing_labels), 1)
+        unique_labels = np.arange(0, np.max(unique_labels) + 1 - len(missing_labels), 1)
 
     tree = KDTree(locations_subset)
 
@@ -143,7 +144,7 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
     global _globs
     _globs = dict(tree=tree, locs=locations_subset, k=15, rdn=rdn_subset, data=data_l2a_seg, bands=bands)
 
-    if platform.system() == "Windows" or processes == 1:
+    if processes == 1:
         initializer(globals(), _globs)
         results = []
         for ii in tqdm(unique_labels, disable=disable_progressbars):
