@@ -12,16 +12,15 @@ from time import time
 from uuid import uuid1
 from xml.etree.ElementTree import QName
 import xml.etree.ElementTree
-import gdal
+from osgeo import gdal, osr
 import glymur
 import iso8601
 import matplotlib.pyplot as plt
 import numpy as np
-import osr
 import pandas as pd
 import pyproj
 from PIL import Image
-from gdalconst import GA_ReadOnly
+from osgeo.gdalconst import GA_ReadOnly
 from geoarray import GeoArray
 from psutil import virtual_memory
 
