@@ -213,7 +213,7 @@ def download_file_from_google_drive(gid, destination):
                 if chunk:  # filter out keep-alive new chunks
                     f.write(chunk)
 
-    URL = "https://docs.google.com/uc?export=download"
+    URL = "https://docs.google.com"
     session = requests.Session()
     response = session.get(URL, params={'id': gid}, stream=True)
     token = get_confirm_token(response)
